@@ -51,7 +51,7 @@ class Parameter():
                     logging.warning('请求参数类型校验失败: {0}'.format(str_data))
                     abort(Response(str_data, 400, {}))
             except KeyError as err:
-                str_data = f'有多余的参数 {err}'
-                logging.warning('多余的请求参数: {0}'.format(str_data))
+                str_data = f'有多余的请求参数: {err}'
+                logging.warning(str_data)
                 abort(Response(str_data, 400, {}))
         return True
